# Journal des modifications

Ce fichier est généré automatiquement après chaque modification du dépôt. 
Les numéros indiqués correspondent aux [versions taggées](https://gitlab.com/canarduck/pays/tags).

## v0.1.0 (2018-02-14)

### ★ Nouveautés

* Génération des fichiers et interface de base.

### ⚔ Correctifs

* Dev-requirements.

